API Reference
=============


Core
----

.. automodule:: antidote.core.injection
    :members:

.. automodule:: antidote.core.container
    :members:

Helpers
-------

.. automodule:: antidote.helpers.register
    :members:

.. automodule:: antidote.helpers.factory
    :members:

.. autoclass:: antidote.helpers.constants.LazyConstantsMeta
   :special-members: __new__

.. automodule:: antidote.helpers.provider
    :members:

.. automodule:: antidote.helpers.container
    :members:

.. automodule:: antidote.helpers.wire
    :members:

.. automodule:: antidote.helpers.implements
    :members:


Providers
---------

Service
^^^^^^^

.. automodule:: antidote.providers.factory
    :members: FactoryProvider,Build

Lazy
^^^^

.. automodule:: antidote.providers.lazy
    :members: LazyCall,LazyMethodCall,LazyCallProvider

Tag
^^^

.. automodule:: antidote.providers.tag
    :members:


Exceptions
----------

.. automodule:: antidote.exceptions
    :members:
